#!/usr/bin/env python3

import argparse
import sys
import struct

parser = argparse.ArgumentParser(description='Packs bits into bytes.')
parser.add_argument('--bits', help='Bits per word', default=8, type=int)
parser.add_argument('--big-endian', help='Use big endian for output', action='store_true')
parser.add_argument('--lsb-first', help='Use less-significant-bit first for input', action='store_true')
args = parser.parse_args()

if args.bits <= 8:
	format = 'B'
elif args.bits <= 16:
	format = 'H'
elif args.bits <= 32:
	format = 'I'

if args.big_endian:
	format = '>' + format

bits = 0
bitCount = 0

while True:
	c = sys.stdin.read(1)
	if c == '':
		break

	if c not in ('0', '1'):
		continue

	bit = c == '1'
	if args.lsb_first:
		bits = bit << (args.bits - 1) | bits >> 1
	else:
		bits = bits << 1 | bit
	bitCount += 1

	if bitCount == args.bits:
		sys.stdout.buffer.write(struct.pack(format, bits))
		bits = 0
		bitCount = 0
