#!/usr/bin/env python3

import argparse
import sys
import struct

parser = argparse.ArgumentParser(description='Unpacks bytes into bits.')
parser.add_argument('--bits', help='Bits per word', default=8, type=int)
parser.add_argument('--big-endian', help='Use big endian for output', action='store_true')
parser.add_argument('--lsb-first', help='Use less-significant-bit first for input', action='store_true')
args = parser.parse_args()

if args.bits <= 8:
	format = 'B'
	readlen = 1
elif args.bits <= 16:
	format = 'H'
	readlen = 2
elif args.bits <= 32:
	format = 'I'
	readlen = 4

if args.big_endian:
	format = '>' + format

while True:
	data = sys.stdin.buffer.read(readlen)
	if len(data) != readlen:
		break

	data = struct.unpack(format, data)
	data = data[0]

	if args.lsb_first:
		for bit in range(args.bits):
			print('1' if data & 1 else '0', end='')
			data = data >> 1
	else:
		mask = (1 << args.bits - 1)
		for bit in range(args.bits):
			print('1' if data & mask else '0', end='')
			data = data << 1

	print(' ', end='')
print()
