#!/usr/bin/env python3

import argparse
import re
import sys
from math import *

DATA_PATTERN = re.compile(r'^(-?\d+)((?:\s+[01])*)\s*$')

parser = argparse.ArgumentParser(description='Parses SPI data.')
parser.add_argument('txtfile', help='Text file with signals', type=argparse.FileType('r'))
parser.add_argument('data', help='Data signal name')
parser.add_argument('clock', help='Clock signal name')
parser.add_argument('--timeout', help='Time between clock events to count as different transmissions', default=25, type=int)
args = parser.parse_args()

for line in args.txtfile:
	if line.startswith('//Channel name:'):
		signals = line[15:].split()
		break
else:
	print('Signal names not found')
	sys.exit(1)

try:
	clockColumn = signals.index(args.clock)
except ValueError:
	print('Clock "%s" not found in signals list: %s' % (args.clock, str(signals)), file=sys.stderr)
	sys.exit(1)

try:
	dataColumn = signals.index(args.data)
except ValueError:
	print('Data "%s" not found in signals list: %s' % (args.data, str(signals)), file=sys.stderr)
	sys.exit(1)

clockWasHigh = False
inTx = False

for line in args.txtfile:
	match = DATA_PATTERN.match(line)
	if not match:
		continue

	frame = int(match.group(1))
	values = match.group(2).split()
	if len(values) != len(signals):
		continue

	clockIsHigh = (values[clockColumn] == '1')

	if clockIsHigh and not clockWasHigh:
		if not inTx:
			print('%10d: ' % frame, end='')
			inTx = True
		clockTimeout = 0
		print(values[dataColumn], end='')
		clockTimeout = 0
	elif inTx:
		clockTimeout += 1
		if clockTimeout == args.timeout:
			print()
			inTx = False

	clockWasHigh = clockIsHigh
